@@ -13,7 +13,7 @@ obtain one at http://mozilla.org/MPL/2.0/.
 ----------------------------------------------------------------------------
 https://www.direct-netware.de/redirect?licenses;mpl2
 ----------------------------------------------------------------------------
-v1.1.1
+v1.1.2
 dpt_logging/exception_log_trap.py
 """
 
@@ -35,7 +35,7 @@ suppressed.
              Mozilla Public License, v. 2.0
     """
 
-    __slots__ = [ "context" ]
+    __slots__ = ( "context", )
     """
 python.org: __slots__ reserves space for the declared variables and prevents
 the automatic creation of __dict__ and __weakref__ for each instance.
